@@ -13,7 +13,8 @@ class NERDADataSetReader():
                 transformer_config: transformers.PretrainedConfig, 
                 max_len: int, 
                 tag_encoder: sklearn.preprocessing.LabelEncoder, 
-                tag_outside: str) -> None:
+                tag_outside: str,
+                pad_sequences : bool) -> None:
         """Initialize DataSetReader
 
         Initializes DataSetReader that prepares and preprocesses 
@@ -39,6 +40,7 @@ class NERDADataSetReader():
         self.tag_encoder = tag_encoder
         self.pad_token_id = transformer_config.pad_token_id
         self.tag_outside_transformed = tag_encoder.transform([tag_outside])[0]
+        self.pad_sequences = pad_sequences
     
     def __len__(self):
         return len(self.sentences)
@@ -93,12 +95,13 @@ class NERDADataSetReader():
 
         # Padding to max length 
         # compute padding length
-        padding_len = self.max_len - len(input_ids)
-        input_ids = input_ids + ([self.pad_token_id] * padding_len)
-        masks = masks + ([0] * padding_len)  
-        offsets = offsets + ([0] * padding_len)
-        token_type_ids = token_type_ids + ([0] * padding_len)
-        target_tags = target_tags + ([self.tag_outside_transformed] * padding_len)  
+        if self.pad_sequences:
+            padding_len = self.max_len - len(input_ids)
+            input_ids = input_ids + ([self.pad_token_id] * padding_len)
+            masks = masks + ([0] * padding_len)  
+            offsets = offsets + ([0] * padding_len)
+            token_type_ids = token_type_ids + ([0] * padding_len)
+            target_tags = target_tags + ([self.tag_outside_transformed] * padding_len)  
     
         return {'input_ids' : torch.tensor(input_ids, dtype = torch.long),
                 'masks' : torch.tensor(masks, dtype = torch.long),
@@ -123,7 +126,9 @@ def create_dataloader(sentences,
         transformer_config = transformer_config,
         max_len = max_len,
         tag_encoder = tag_encoder,
-        tag_outside = tag_outside)
+        tag_outside = tag_outside,
+        pad_sequences = batch_size > 1)
+        # Don't pad sequences if batch size == 1. This improves performance.
 
     data_loader = torch.utils.data.DataLoader(
         data_reader, batch_size = batch_size, num_workers = num_workers
